@@ -15,6 +15,7 @@ def read_asset(*paths):
 
 VERSION = read_asset("VERSION")
 TEMPLATES = os.path.join(os.path.dirname(__file__), "assets", "templates")
+# TODO: rebase fully on Jinja's directory loader
 LAYOUT = read_asset("templates", "layout.html")
-TABLE = read_asset("templates", "table.html")
-CHART = read_asset("templates", "chart.html")
+TABLE = read_asset("templates", "features", "table.html")
+CHART = read_asset("templates", "features", "chart.html")
