@@ -1,7 +1,9 @@
+import os
 import yaml
 import marko
 import subprocess
 import frictionless
+from datetime import datetime
 from marko.ext.gfm import GFM
 from jinja2 import Environment, FileSystemLoader
 from .renderer import LivemarkExtension, LivemarkRendererMixin
@@ -35,9 +37,11 @@ class Document:
             metadata = yaml.safe_load(frontmatter)
             # TODO: find a better place for it
             metadata.setdefault("title", "Livemark")
+            metadata.setdefault("time", {})
+            metadata["time"]["current"] = datetime.fromtimestamp(
+                os.path.getmtime(self.__path)
+            )
             # TODO: set these in the renderer
-            metadata["table"] = True
-            metadata["chart"] = True
             metadata["markup"] = True
             # TODO: it's a hack as marko doesn't have context
             LivemarkRendererMixin.metadata = metadata
